@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.106';
+our $VERSION = '0.107';
 use 5.006;
 use strict;
 use warnings;
@@ -89,7 +89,7 @@ sub run {
 		$j->sid = $h->hexdigest;
 	}
 
-	$j->cookie = {
+	$j->sid = {
 		value => $j->is_logout ? "" : $j->sid,
 		path  => $j->request->uri,
 		secure => !$j->{_insecure_session},
@@ -108,8 +108,8 @@ sub run {
 	$j->response->authenticated = \1;
 	$j->session = $session;
 
-	$j->cookie->expires = (ref $j->session && $j->session->expires) || (time + 24 * 60 * 60) 
-		if (!$j->cookie->expires);
+	$j->sid->expires = (ref $j->session && $j->session->expires) || (time + 24 * 60 * 60) 
+		if (!$j->sid->expires);
 
 	($j->is_login, $j->is_logout) = (
 		$j->{_login} eq $req,
@@ -129,22 +129,30 @@ sub run {
 		return $j->_response($j->response);
 	}
 
-	return $j->_response($j->response, $j->content_type, $j->cookie);
+	return $j->_response($j->response, $j->content_type, $j->sid);
+}
+
+sub _build_response {
+	my ($self, $sid, $content, $status) = @_;
+	my $res = $self->request->new_response($self->response->{status_code} ||= $status);
+	$res->cookies($self->cookies) if $self->cookies;
+	$res->headers($self->headers) if $self->headers;
+	$res->cookies->{sid} = $sid if $sid;
+	$res->content_type($content);
+	return $res;
 }
 
 sub delayed_response {
-	my ($self, $response, $ct, $cookie, $status) = @_;
-	$cookie ||= $self->cookie;
+	my ($self, $response, $sid, $ct, $status) = @_;
+	$sid ||= $self->sid;
 	$status ||= 200;
 	$ct ||= 'application/json';
 	return $self->{_application}->delayed_response_handle(
-		$self, $response, $ct, $cookie, $status
+		$self, $response, $sid, $ct, $status
 	) if $self->{_application_has_delayed_response_handler};
 	$self->{_delayed_response} = sub {
 		my $responder = shift;
-		my $res = $self->request->new_response($self->response->{status_code} ||= $status);
-		$res->cookies->{sid} = $cookie if $cookie;
-		$res->content_type($ct);
+		my $res = $self->_build_response($sid, $ct, $status);
 		$res = [splice @{$res->finalize}, 0, 2];
 		my $writer = $responder->($res);
 		$response = eval { $response->($writer); };
@@ -168,14 +176,12 @@ sub content_type {
 }
 
 sub _response {
-	my ($self, $response_body, $ct, $cookie, $status) = @_;
+	my ($self, $response_body, $sid, $ct, $status) = @_;
 	return $self->{_application}->response_handle(@_) if $self->{_application_has_response_handler};
 	$ct ||= 'application/json';
 	my $res = $self->{_delayed_response};
 	return $res if ($res); 
-	$res = $self->request->new_response($response_body->status_code ||= $status ||= 200);
-	$res->cookies->{sid} = $cookie if $cookie;
-	$res->content_type($ct);
+	$res = $self->_build_response($sid, $ct, $status);
 	$res->body($response_body->serialize());
 	return $res->finalize;
 }
@@ -318,7 +324,7 @@ Terse - Lightweight JSON APIs.
 
 =head1 VERSION
 
-Version 0.106
+Version 0.107
 
 =cut
 
