@@ -122,13 +122,14 @@ sub PARSE_ATTRIBUTES {
 }
 
 sub delayed_response_handle {
-	my ($self, $t,  $response, $ct, $cookie, $status) = @_;
+	my ($self, $t,  $response, $sid, $ct, $status) = @_;
 	$t->{_delayed_response} = sub {
 		my $responder = shift;
-		my $res = $t->request->new_response($t->response->status_code ||= $status);
-		$res->cookies->{sid} = $cookie if $cookie;
 		my $view = $t->view($self->response_view);
-		$res->content_type( $view ? $view->content_type($ct) : $ct);
+		my $res = $t->_build_response($sid, 
+			$view ? ($view->content_type || $view->content_type($ct)) : $ct, 
+			$t->response->status_code ||= $status ||= 200
+		);
 		$res = [splice @{$res->finalize}, 0, 2];
 		my $writer = $responder->($res);
 		$response = eval { $response->($writer); };
@@ -149,16 +150,14 @@ sub delayed_response_handle {
 
 
 sub response_handle {
-	my ($self, $t, $response_body, $ct, $cookie, $status) = @_;
+	my ($self, $t, $response_body, $sid, $ct, $status) = @_;
 	$ct ||= 'application/json';
 	my $res = $t->{_delayed_response};
-	return $res if ($res); 
-	$res = $t->request->new_response($response_body->status_code ||= $status ||= 200);
-	$res->cookies->{sid} = $cookie if $cookie;
+	return $res if ($res);
 	my ($content_type, $body) = $self->views->{$self->response_view} 
 		? $t->view($self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
-	$res->content_type($content_type);
+	my $res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
 	$res->body($body);
 	return $res->finalize;
 }
@@ -232,7 +231,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.106
+Version 0.107
 
 =cut
 
