@@ -2,6 +2,10 @@ package Test::App;
 
 use base 'Terse::App';
 
+sub build_app {
+	$_[0]->response_view = 'pretty';
+}
+
 sub login :any {
 	return 1;
 }
